/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_da extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AUD", "AU$" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "kr." },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMK", "ZMK" },
            { "ZMW", "ZMW" },
            { "adp", "Andorransk peseta" },
            { "aed", "dirham fra de Forenede Arabiske Emirater" },
            { "afa", "Afghansk afghani (1927\u20132002)" },
            { "afn", "afghansk afghani" },
            { "all", "albansk lek" },
            { "amd", "armensk dram" },
            { "ang", "Nederlandske Antiller-gylden" },
            { "aoa", "angolansk kwanza" },
            { "aok", "Angolansk kwanza (1977\u20131990)" },
            { "aon", "Angolansk nye kwanza (1990\u20132000)" },
            { "aor", "Angolansk kwanza (1995\u20131999)" },
            { "ara", "Argentinsk austral" },
            { "arp", "Argentinsk peso (1983\u20131985)" },
            { "ars", "argentinsk peso" },
            { "ats", "\u00d8strigsk schilling" },
            { "aud", "australsk dollar" },
            { "awg", "arubansk florin" },
            { "azm", "Aserbajdsjansk manat (1993\u20132006)" },
            { "azn", "aserbajdsjansk manat" },
            { "bad", "Bosnien-Hercegovinsk dinar" },
            { "bam", "bosnien-hercegovinsk konvertibel mark" },
            { "bbd", "barbadisk dollar" },
            { "bdt", "bangladeshisk taka" },
            { "bec", "Belgisk franc (konvertibel)" },
            { "bef", "Belgisk franc" },
            { "bel", "Belgisk franc (financial)" },
            { "bgl", "Bulgarsk hard lev" },
            { "bgn", "bulgarsk lev" },
            { "bhd", "bahrainsk dinar" },
            { "bif", "burundisk franc" },
            { "bmd", "bermudansk dollar" },
            { "bnd", "bruneisk dollar" },
            { "bob", "boliviansk boliviano" },
            { "bop", "Boliviansk peso" },
            { "bov", "Boliviansk mvdol" },
            { "brb", "Brasiliansk cruzeiro novo (1967\u20131986)" },
            { "brc", "Brasiliansk cruzado (1986\u20131989)" },
            { "bre", "Brasiliansk cruzeiro (1990\u20131993)" },
            { "brl", "brasiliansk real" },
            { "brn", "Brasiliansk cruzado novo (1989\u20131990)" },
            { "brr", "Brasiliansk cruzeiro (1993\u20131994)" },
            { "bsd", "bahamansk dollar" },
            { "btn", "bhutansk ngultrum" },
            { "buk", "Burmesisk kyat" },
            { "bwp", "botswansk pula" },
            { "byb", "Hviderussisk rubel (1994\u20131999)" },
            { "byn", "hviderussisk rubel" },
            { "byr", "hviderussisk rubel (2000\u20132016)" },
            { "bzd", "belizisk dollar" },
            { "cad", "canadisk dollar" },
            { "cdf", "congolesisk franc" },
            { "che", "WIR euro" },
            { "chf", "schweizerfranc" },
            { "chw", "WIR franc" },
            { "clp", "chilensk peso" },
            { "cnh", "kinesisk yuan (offshore)" },
            { "cny", "kinesisk yuan" },
            { "cop", "colombiansk peso" },
            { "crc", "costaricansk col\u00f3n" },
            { "csd", "Serbisk dinar (2002\u20132006)" },
            { "csk", "Tjekkoslovakisk hard koruna" },
            { "cuc", "cubansk konvertibel peso" },
            { "cup", "cubansk peso" },
            { "cve", "kapverdisk escudo" },
            { "cyp", "Cypriotisk pund" },
            { "czk", "tjekkisk koruna" },
            { "ddm", "\u00d8sttysk mark" },
            { "dem", "Tysk mark" },
            { "djf", "djiboutisk franc" },
            { "dkk", "dansk krone" },
            { "dop", "dominikansk peso" },
            { "dzd", "algerisk dinar" },
            { "ecs", "Ecuadoriansk sucre" },
            { "eek", "Estisk kroon" },
            { "egp", "egyptisk pund" },
            { "ern", "eritreisk nakfa" },
            { "esa", "Spansk peseta (A\u2013konto)" },
            { "esb", "Spansk peseta (konvertibel konto)" },
            { "esp", "Spansk peseta" },
            { "etb", "etiopisk birr" },
            { "eur", "euro" },
            { "fim", "Finsk mark" },
            { "fjd", "fijiansk dollar" },
            { "fkp", "pund fra Falklands\u00f8erne" },
            { "frf", "Fransk franc" },
            { "gbp", "britisk pund" },
            { "gek", "Georgisk kupon larit" },
            { "gel", "georgisk lari" },
            { "ghc", "Ghanesisk cedi (1979\u20132007)" },
            { "ghs", "ghanesisk cedi" },
            { "gip", "gibraltarisk pund" },
            { "gmd", "gambisk dalasi" },
            { "gnf", "guineansk franc" },
            { "gns", "Guineansk syli" },
            { "gqe", "\u00c6kvatorialguineask ekwele" },
            { "grd", "Gr\u00e6sk drakme" },
            { "gtq", "guatemalansk quetzal" },
            { "gwe", "Portugisisk guinea escudo" },
            { "gwp", "Guineansk peso" },
            { "gyd", "guyansk dollar" },
            { "hkd", "hongkongsk dollar" },
            { "hnl", "honduransk lempira" },
            { "hrd", "Kroatisk dinar" },
            { "hrk", "kroatisk kuna" },
            { "htg", "haitisk gourde" },
            { "huf", "ungarsk forint" },
            { "idr", "indonesisk rupiah" },
            { "iep", "Irsk pund" },
            { "ilp", "Israelsk pund" },
            { "ils", "ny israelsk shekel" },
            { "inr", "indisk rupee" },
            { "iqd", "irakisk dinar" },
            { "irr", "iransk rial" },
            { "isk", "islandsk krone" },
            { "itl", "Italiensk lire" },
            { "jmd", "jamaicansk dollar" },
            { "jod", "jordansk dinar" },
            { "jpy", "japansk yen" },
            { "kes", "kenyansk shilling" },
            { "kgs", "kirgisisk som" },
            { "khr", "cambodjansk riel" },
            { "kmf", "comorisk franc" },
            { "kpw", "nordkoreansk won" },
            { "krw", "sydkoreansk won" },
            { "kwd", "kuwaitisk dinar" },
            { "kyd", "caymansk dollar" },
            { "kzt", "kasakhisk tenge" },
            { "lak", "laotisk kip" },
            { "lbp", "libanesisk pund" },
            { "lkr", "srilankansk rupee" },
            { "lrd", "liberisk dollar" },
            { "lsl", "Lesothisk loti" },
            { "ltl", "Litauisk litas" },
            { "ltt", "Litauisk talonas" },
            { "luc", "Luxembourgsk konvertibel franc" },
            { "luf", "Luxembourgsk franc" },
            { "lul", "Luxembourgsk finansiel franc" },
            { "lvl", "Lettisk lat" },
            { "lvr", "Lettisk rubel" },
            { "lyd", "libysk dinar" },
            { "mad", "marokkansk dirham" },
            { "maf", "Marokkansk franc" },
            { "mdl", "moldovisk leu" },
            { "mga", "madagaskisk ariary" },
            { "mgf", "Madagaskisk franc" },
            { "mkd", "makedonsk denar" },
            { "mlf", "Malisk franc" },
            { "mmk", "myanmarsk kyat" },
            { "mnt", "mongolsk tugrik" },
            { "mop", "macaosk pataca" },
            { "mro", "mauritansk ouguiya (1973\u20132017)" },
            { "mru", "mauritansk ouguiya" },
            { "mtl", "Maltesisk lira" },
            { "mtp", "Maltesisk pund" },
            { "mur", "mauritisk rupee" },
            { "mvr", "maldivisk rufiyaa" },
            { "mwk", "malawisk kwacha" },
            { "mxn", "mexicansk peso" },
            { "mxp", "Mexicansk silver peso (1861\u20131992)" },
            { "myr", "malaysisk ringgit" },
            { "mze", "Mozambiquisk escudo" },
            { "mzm", "Mozambiquisk metical (1980\u20132006)" },
            { "mzn", "mozambiquisk metical" },
            { "nad", "namibisk dollar" },
            { "ngn", "nigeriansk naira" },
            { "nic", "Nicaraguansk cordoba (1988\u20131991)" },
            { "nio", "nicaraguansk cordoba" },
            { "nlg", "Hollandsk guilder" },
            { "nok", "norsk krone" },
            { "npr", "nepalesisk rupee" },
            { "nzd", "newzealandsk dollar" },
            { "omr", "omansk rial" },
            { "pab", "panamansk balboa" },
            { "pei", "peruviansk inti" },
            { "pen", "peruansk sol" },
            { "pes", "peruviansk sol (1863\u20131965)" },
            { "pgk", "papuansk kina" },
            { "php", "filippinsk peso" },
            { "pkr", "pakistansk rupee" },
            { "pln", "polsk zloty" },
            { "plz", "Polsk zloty (1950\u20131995)" },
            { "pte", "Portugisisk escudo" },
            { "pyg", "paraguaysk guarani" },
            { "qar", "qatarsk rial" },
            { "rol", "Rum\u00e6nsk leu (1952\u20132006)" },
            { "ron", "rum\u00e6nsk leu" },
            { "rsd", "serbisk dinar" },
            { "rub", "russisk rubel" },
            { "rur", "Russisk rubel (1991\u20131998)" },
            { "rwf", "rwandisk franc" },
            { "sar", "saudiarabisk riyal" },
            { "sbd", "salomonsk dollar" },
            { "scr", "seychellisk rupee" },
            { "sdd", "Sudansk dinar (1992\u20132007)" },
            { "sdg", "sudansk pund" },
            { "sdp", "Sudansk pund (1957\u20131998)" },
            { "sek", "svensk krone" },
            { "sgd", "singaporeansk dollar" },
            { "shp", "pund fra Saint Helena" },
            { "sit", "Slovensk tolar" },
            { "skk", "Slovakisk koruna" },
            { "sll", "sierraleonsk leone" },
            { "sos", "somalisk shilling" },
            { "srd", "surinamsk dollar" },
            { "srg", "Surinamsk guilder" },
            { "ssp", "sydsudansk pund" },
            { "std", "dobra fra Sao Tome og Principe (1977\u20132017)" },
            { "stn", "dobra fra Sao Tome og Principe" },
            { "sur", "Sovjetisk rubel" },
            { "svc", "Salvadoransk colon" },
            { "syp", "syrisk pund" },
            { "szl", "swazilandsk lilangeni" },
            { "thb", "thailandsk baht" },
            { "tjr", "Tadsjikisk rubel" },
            { "tjs", "tadsjikisk somoni" },
            { "tmm", "Turkmensk manat (1993\u20132009)" },
            { "tmt", "turkmensk manat" },
            { "tnd", "tunesisk dinar" },
            { "top", "tongansk pa\u02bbanga" },
            { "tpe", "Escudo fra Timor" },
            { "trl", "Tyrkisk lire (1922\u20132005)" },
            { "try", "tyrkisk lira" },
            { "ttd", "dollar fra Trinidad og Tobago" },
            { "twd", "ny taiwansk dollar" },
            { "tzs", "tanzanisk shilling" },
            { "uah", "ukrainsk grynia" },
            { "uak", "Ukrainsk karbovanetz" },
            { "ugs", "Ugandisk shilling (1966\u20131987)" },
            { "ugx", "ugandisk shilling" },
            { "usd", "amerikansk dollar" },
            { "usn", "Amerikansk dollar (n\u00e6ste dag)" },
            { "uss", "Amerikansk dollar (samme dag)" },
            { "uyp", "Uruguayansk peso (1975\u20131993)" },
            { "uyu", "uruguayansk peso" },
            { "uzs", "usbekisk sum" },
            { "veb", "Venezuelansk bolivar (1871\u20132008)" },
            { "vef", "venezuelansk bolivar (2008\u20132018)" },
            { "ves", "venezuelansk bolivar" },
            { "vnd", "vietnamesisk dong" },
            { "vuv", "vanuaisk vatu" },
            { "wst", "samoansk tala" },
            { "xaf", "CFA-franc (BEAC)" },
            { "xag", "S\u00f8lv" },
            { "xau", "Guld" },
            { "xba", "EURCO" },
            { "xbb", "EMU" },
            { "xcd", "\u00f8stkaribisk dollar" },
            { "xdr", "SDR" },
            { "xeu", "ECU" },
            { "xfo", "Fransk guldfranc" },
            { "xfu", "Fransk UIC-franc" },
            { "xof", "CFA-franc BCEAO" },
            { "xpd", "Palladium" },
            { "xpf", "CFP-franc" },
            { "xpt", "Platin" },
            { "xre", "RINET-fond" },
            { "xts", "testvalutakode" },
            { "xxx", "ukendt valuta" },
            { "ydd", "Yemenitisk dinar" },
            { "yer", "yemenitisk rial" },
            { "yud", "Jugoslavisk hard dinar (1966\u20131990)" },
            { "yum", "Jugoslavisk noviy dinar (1994\u20132002)" },
            { "yun", "Jugoslavisk konvertibel dinar (1990\u20131992)" },
            { "zal", "Sydafrikansk rand (financial)" },
            { "zar", "sydafrikansk rand" },
            { "zmk", "Zambisk kwacha (1968\u20132012)" },
            { "zmw", "zambisk kwacha" },
            { "zrn", "Ny zairisk zaire (1993\u20131998)" },
            { "zrz", "Zairisk zaire (1971\u20131993)" },
            { "zwd", "Zimbabwisk dollar (1980\u20132008)" },
            { "zwl", "Zimbabwisk dollar (2009)" },
            { "zwr", "Zimbabwisk dollar (2008)" },
        };
        return data;
    }
}
